@@ -93,7 +93,7 @@ class Exceptions:
 
 class BackupClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html)
     """
 
@@ -102,7 +102,7 @@ class BackupClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#can_paginate)
         """
 
@@ -114,7 +114,7 @@ class BackupClient:
         CreatorRequestId: str = None
     ) -> CreateBackupPlanOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.create_backup_plan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.create_backup_plan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#create_backup_plan)
         """
 
@@ -126,7 +126,7 @@ class BackupClient:
         CreatorRequestId: str = None
     ) -> CreateBackupSelectionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.create_backup_selection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.create_backup_selection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#create_backup_selection)
         """
 
@@ -139,109 +139,109 @@ class BackupClient:
         CreatorRequestId: str = None
     ) -> CreateBackupVaultOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.create_backup_vault)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.create_backup_vault)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#create_backup_vault)
         """
 
-    def delete_backup_plan(self, BackupPlanId: str) -> DeleteBackupPlanOutputTypeDef:
+    def delete_backup_plan(self, *, BackupPlanId: str) -> DeleteBackupPlanOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.delete_backup_plan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.delete_backup_plan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#delete_backup_plan)
         """
 
-    def delete_backup_selection(self, BackupPlanId: str, SelectionId: str) -> None:
+    def delete_backup_selection(self, *, BackupPlanId: str, SelectionId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.delete_backup_selection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.delete_backup_selection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#delete_backup_selection)
         """
 
-    def delete_backup_vault(self, BackupVaultName: str) -> None:
+    def delete_backup_vault(self, *, BackupVaultName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.delete_backup_vault)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.delete_backup_vault)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#delete_backup_vault)
         """
 
-    def delete_backup_vault_access_policy(self, BackupVaultName: str) -> None:
+    def delete_backup_vault_access_policy(self, *, BackupVaultName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.delete_backup_vault_access_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.delete_backup_vault_access_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#delete_backup_vault_access_policy)
         """
 
-    def delete_backup_vault_notifications(self, BackupVaultName: str) -> None:
+    def delete_backup_vault_notifications(self, *, BackupVaultName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.delete_backup_vault_notifications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.delete_backup_vault_notifications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#delete_backup_vault_notifications)
         """
 
-    def delete_recovery_point(self, BackupVaultName: str, RecoveryPointArn: str) -> None:
+    def delete_recovery_point(self, *, BackupVaultName: str, RecoveryPointArn: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.delete_recovery_point)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.delete_recovery_point)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#delete_recovery_point)
         """
 
-    def describe_backup_job(self, BackupJobId: str) -> DescribeBackupJobOutputTypeDef:
+    def describe_backup_job(self, *, BackupJobId: str) -> DescribeBackupJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.describe_backup_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.describe_backup_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#describe_backup_job)
         """
 
-    def describe_backup_vault(self, BackupVaultName: str) -> DescribeBackupVaultOutputTypeDef:
+    def describe_backup_vault(self, *, BackupVaultName: str) -> DescribeBackupVaultOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.describe_backup_vault)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.describe_backup_vault)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#describe_backup_vault)
         """
 
-    def describe_copy_job(self, CopyJobId: str) -> DescribeCopyJobOutputTypeDef:
+    def describe_copy_job(self, *, CopyJobId: str) -> DescribeCopyJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.describe_copy_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.describe_copy_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#describe_copy_job)
         """
 
     def describe_global_settings(self) -> DescribeGlobalSettingsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.describe_global_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.describe_global_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#describe_global_settings)
         """
 
     def describe_protected_resource(
-        self, ResourceArn: str
+        self, *, ResourceArn: str
     ) -> DescribeProtectedResourceOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.describe_protected_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.describe_protected_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#describe_protected_resource)
         """
 
     def describe_recovery_point(
-        self, BackupVaultName: str, RecoveryPointArn: str
+        self, *, BackupVaultName: str, RecoveryPointArn: str
     ) -> DescribeRecoveryPointOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.describe_recovery_point)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.describe_recovery_point)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#describe_recovery_point)
         """
 
     def describe_region_settings(self) -> DescribeRegionSettingsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.describe_region_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.describe_region_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#describe_region_settings)
         """
 
-    def describe_restore_job(self, RestoreJobId: str) -> DescribeRestoreJobOutputTypeDef:
+    def describe_restore_job(self, *, RestoreJobId: str) -> DescribeRestoreJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.describe_restore_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.describe_restore_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#describe_restore_job)
         """
 
-    def disassociate_recovery_point(self, BackupVaultName: str, RecoveryPointArn: str) -> None:
+    def disassociate_recovery_point(self, *, BackupVaultName: str, RecoveryPointArn: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.disassociate_recovery_point)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.disassociate_recovery_point)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#disassociate_recovery_point)
         """
 
     def export_backup_plan_template(
-        self, BackupPlanId: str
+        self, *, BackupPlanId: str
     ) -> ExportBackupPlanTemplateOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.export_backup_plan_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.export_backup_plan_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#export_backup_plan_template)
         """
 
@@ -253,69 +253,69 @@ class BackupClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#generate_presigned_url)
         """
 
     def get_backup_plan(
-        self, BackupPlanId: str, VersionId: str = None
+        self, *, BackupPlanId: str, VersionId: str = None
     ) -> GetBackupPlanOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.get_backup_plan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.get_backup_plan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#get_backup_plan)
         """
 
     def get_backup_plan_from_json(
-        self, BackupPlanTemplateJson: str
+        self, *, BackupPlanTemplateJson: str
     ) -> GetBackupPlanFromJSONOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.get_backup_plan_from_json)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.get_backup_plan_from_json)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#get_backup_plan_from_json)
         """
 
     def get_backup_plan_from_template(
-        self, BackupPlanTemplateId: str
+        self, *, BackupPlanTemplateId: str
     ) -> GetBackupPlanFromTemplateOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.get_backup_plan_from_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.get_backup_plan_from_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#get_backup_plan_from_template)
         """
 
     def get_backup_selection(
-        self, BackupPlanId: str, SelectionId: str
+        self, *, BackupPlanId: str, SelectionId: str
     ) -> GetBackupSelectionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.get_backup_selection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.get_backup_selection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#get_backup_selection)
         """
 
     def get_backup_vault_access_policy(
-        self, BackupVaultName: str
+        self, *, BackupVaultName: str
     ) -> GetBackupVaultAccessPolicyOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.get_backup_vault_access_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.get_backup_vault_access_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#get_backup_vault_access_policy)
         """
 
     def get_backup_vault_notifications(
-        self, BackupVaultName: str
+        self, *, BackupVaultName: str
     ) -> GetBackupVaultNotificationsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.get_backup_vault_notifications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.get_backup_vault_notifications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#get_backup_vault_notifications)
         """
 
     def get_recovery_point_restore_metadata(
-        self, BackupVaultName: str, RecoveryPointArn: str
+        self, *, BackupVaultName: str, RecoveryPointArn: str
     ) -> GetRecoveryPointRestoreMetadataOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.get_recovery_point_restore_metadata)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.get_recovery_point_restore_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#get_recovery_point_restore_metadata)
         """
 
     def get_supported_resource_types(self) -> GetSupportedResourceTypesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.get_supported_resource_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.get_supported_resource_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#get_supported_resource_types)
         """
 
@@ -333,15 +333,15 @@ class BackupClient:
         ByAccountId: str = None
     ) -> ListBackupJobsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_backup_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_backup_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_backup_jobs)
         """
 
     def list_backup_plan_templates(
-        self, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = None, MaxResults: int = None
     ) -> ListBackupPlanTemplatesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_backup_plan_templates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_backup_plan_templates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_backup_plan_templates)
         """
 
@@ -349,7 +349,7 @@ class BackupClient:
         self, *, BackupPlanId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListBackupPlanVersionsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_backup_plan_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_backup_plan_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_backup_plan_versions)
         """
 
@@ -357,7 +357,7 @@ class BackupClient:
         self, *, NextToken: str = None, MaxResults: int = None, IncludeDeleted: bool = None
     ) -> ListBackupPlansOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_backup_plans)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_backup_plans)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_backup_plans)
         """
 
@@ -365,15 +365,15 @@ class BackupClient:
         self, *, BackupPlanId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListBackupSelectionsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_backup_selections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_backup_selections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_backup_selections)
         """
 
     def list_backup_vaults(
-        self, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = None, MaxResults: int = None
     ) -> ListBackupVaultsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_backup_vaults)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_backup_vaults)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_backup_vaults)
         """
 
@@ -391,15 +391,15 @@ class BackupClient:
         ByAccountId: str = None
     ) -> ListCopyJobsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_copy_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_copy_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_copy_jobs)
         """
 
     def list_protected_resources(
-        self, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = None, MaxResults: int = None
     ) -> ListProtectedResourcesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_protected_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_protected_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_protected_resources)
         """
 
@@ -416,7 +416,7 @@ class BackupClient:
         ByCreatedAfter: datetime = None
     ) -> ListRecoveryPointsByBackupVaultOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_recovery_points_by_backup_vault)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_recovery_points_by_backup_vault)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_recovery_points_by_backup_vault)
         """
 
@@ -424,7 +424,7 @@ class BackupClient:
         self, *, ResourceArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListRecoveryPointsByResourceOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_recovery_points_by_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_recovery_points_by_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_recovery_points_by_resource)
         """
 
@@ -439,7 +439,7 @@ class BackupClient:
         ByStatus: RestoreJobStatusType = None
     ) -> ListRestoreJobsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_restore_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_restore_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_restore_jobs)
         """
 
@@ -447,13 +447,13 @@ class BackupClient:
         self, *, ResourceArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListTagsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#list_tags)
         """
 
-    def put_backup_vault_access_policy(self, BackupVaultName: str, Policy: str = None) -> None:
+    def put_backup_vault_access_policy(self, *, BackupVaultName: str, Policy: str = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.put_backup_vault_access_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.put_backup_vault_access_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#put_backup_vault_access_policy)
         """
 
@@ -465,7 +465,7 @@ class BackupClient:
         BackupVaultEvents: List[BackupVaultEventType]
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.put_backup_vault_notifications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.put_backup_vault_notifications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#put_backup_vault_notifications)
         """
 
@@ -483,7 +483,7 @@ class BackupClient:
         BackupOptions: Dict[str, str] = None
     ) -> StartBackupJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.start_backup_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.start_backup_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#start_backup_job)
         """
 
@@ -498,7 +498,7 @@ class BackupClient:
         Lifecycle: "LifecycleTypeDef" = None
     ) -> StartCopyJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.start_copy_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.start_copy_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#start_copy_job)
         """
 
@@ -512,39 +512,39 @@ class BackupClient:
         ResourceType: str = None
     ) -> StartRestoreJobOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.start_restore_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.start_restore_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#start_restore_job)
         """
 
-    def stop_backup_job(self, BackupJobId: str) -> None:
+    def stop_backup_job(self, *, BackupJobId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.stop_backup_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.stop_backup_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#stop_backup_job)
         """
 
-    def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
+    def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#tag_resource)
         """
 
-    def untag_resource(self, ResourceArn: str, TagKeyList: List[str]) -> None:
+    def untag_resource(self, *, ResourceArn: str, TagKeyList: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#untag_resource)
         """
 
     def update_backup_plan(
-        self, BackupPlanId: str, BackupPlan: BackupPlanInputTypeDef
+        self, *, BackupPlanId: str, BackupPlan: BackupPlanInputTypeDef
     ) -> UpdateBackupPlanOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.update_backup_plan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.update_backup_plan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#update_backup_plan)
         """
 
-    def update_global_settings(self, GlobalSettings: Dict[str, str] = None) -> None:
+    def update_global_settings(self, *, GlobalSettings: Dict[str, str] = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.update_global_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.update_global_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#update_global_settings)
         """
 
@@ -552,12 +552,14 @@ class BackupClient:
         self, *, BackupVaultName: str, RecoveryPointArn: str, Lifecycle: "LifecycleTypeDef" = None
     ) -> UpdateRecoveryPointLifecycleOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.update_recovery_point_lifecycle)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.update_recovery_point_lifecycle)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#update_recovery_point_lifecycle)
         """
 
-    def update_region_settings(self, ResourceTypeOptInPreference: Dict[str, bool] = None) -> None:
+    def update_region_settings(
+        self, *, ResourceTypeOptInPreference: Dict[str, bool] = None
+    ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/backup.html#Backup.Client.update_region_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/backup.html#Backup.Client.update_region_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_backup/client.html#update_region_settings)
         """
